OC.L10N.register(
    "app_api",
    {
    "Daemon config not found" : "Nastavení pro proces služby nenalezeno",
    "Error starting install of ExApp" : "Chyba při zahajování instalace ExApp",
    "ExApp failed to register, check the NC logs" : "ExApp se nepodařilo zaregistrovat – nahlédněte do záznamů událostí v Nextcloud",
    "ExApp not found, failed to get status" : "ExApp nenalezena, nepodařilo se získat stav",
    "Error adding Docker registry" : "Chyba při přidávání Docker registru",
    "Error removing Docker registry" : "Chyba při odebírání Docker registru",
    "This app is not installed from the AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Tato aplikace nebyla nainstalována z katalogu aplikací. Tím nejsou k dispozici žádné další informace. Je možné pouze zapnout/vypnout a odebrat.",
    "Could not perform installation of ExApp" : "Nebylo možné provést instalaci ExApp",
    "Failed to enable ExApp" : "Nepodařilo se zapnout ExApp",
    "Failed to disable ExApp" : "Nepodařil ose vypnout ExApp",
    "Could not update ExApp" : "Nepodařilo se zaktualizovat ExApp",
    "Error starting update of ExApp" : "Chyba při zahajování aktualizace ExApp",
    "Could not perform update of ExApp" : "Nebylo možné provést aktualizaci ExApp",
    "ExApp not found, failed to get logs" : "ExApp nenalezena, nepodařilo se získat záznamy událostí",
    "Failed to get container logs. Note: Downloading Docker container works only for containers with the json-file or journald logging driver. Error: %s" : "Nepodařilo se získat záznamy událostí v kontejneru. Pozn.: Stahování docker kontejneru funguje pouze pro kontejnery s ovladačem zaznamenávání json-file nebo journald. Chyba: %s",
    "ExApp not found, failed to get deploy options" : "ExApp nenalezena, nepodařilo se získat předvolby nasazení",
    "AppAPI authentication failed" : "ověřování vůči AppAPI se nezdařilo",
    "AppAPI ExApp notifier" : "Upozorňování AppAPI ExApp",
    "AppAPI" : "AppAPI",
    "AI Integration Team" : "Tým napojení AI",
    "ExApps Settings" : "Nastavení pro ExApps",
    "AppAPI deploy daemon" : "AppAPI proces služby nasazování",
    "AppAPI default deploy daemon is not set. Please register a default deploy daemon in the settings to install External Apps (Ex-Apps)." : "Výchozí AppAPI proces služby nasazování není nastavený. Zaregistrujte takový v nastavení pro instalaci Externích aplikací (Ex-Apps).",
    "AppAPI default deploy daemon \"%s\" is not accessible. Please check the daemon configuration." : "Výchozí AppAPI proces služby nasazování „%s“ není dostupný. Ověřte její nastavení",
    "The AppAPI default deploy daemon is not using HaRP. Please consider switching to HaRP for better performance." : "Výchozí AppAPI proces služby nasazování nepoužívá HaRP. Zvažte přechod na něj a vylepšete tak výkon.",
    "Nextcloud AppAPI" : "Nextcloud AppAPI",
    "External Apps management" : "Správa externích aplikací",
    "Admin options saved" : "Předvolby pro správu uloženy",
    "Failed to save admin options" : "Předvolby pro správu se nepodařilo uložit",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud through the use of docker containers. Allowing for greater programming language choice and allowing computationally expensive tasks to be offloaded to a different server." : "Projekt AppAPI je vzrušující iniciativa, která cílí na zmodernizování vývoje aplikací pro Nextcloud s pomocí docker kontejnerů. To umožňuje širší volbu programovacích jazyků a delegování výpočetně náročnějších úloh na jiný server.",
    "Deploy daemons" : "Nasadit procesy služeb",
    "A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Proces služby nasazování (DaemonConfig) slouží pro orchestraci ExApps.",
    "Deploy daemons. A deploy daemon (DaemonConfig) is an ExApps orchestration daemon." : "Procesy nasazování. Proces služby nasazování (DaemonConfig) slouží pro orchestraci ExApps.",
    "Default deploy daemon is not accessible. Please check its configuration" : "Výchozí proces služby nasazování není dostupný. Zkontrolujte její nastavení",
    "ExApp init timeout (minutes)" : "Časový limit inicializace ExApp (minuty)",
    "ExApp initialization process timeout after which AppAPI will mark it as failed" : "Časový limit pro inicializaci ExApp po jehož uplynutí ji AppAPI označí za nezdařenou",
    "ExApp init timeout" : "Časový limit inicializace ExApp",
    "ExApp container restart policy" : "Zásada restartu kontejneru s ExApp",
    "Choose the container restart policy, e.g. 'always' to ensure ExApps will be running after a daemon server reboot" : "Zvolte zásadu pro restartování kontejneru – například 'always', která zajistí že ExApp aplikace budou spuštěné po restartu serveru s procesem služby",
    "This settings changes are effective only for newly created containers" : "Změny tohoto nastavení se budou týkat pouze nově vytvářených kontejnerů",
    "Deploy daemon deletion confirmation" : "Potvrzení smazání procesu služby nasazování",
    "Are you sure you want delete the \"{name}\" deploy daemon?" : "Opravdu chcete proces nasazování „{name}“ smazat?",
    "Remove all ExApps installed on this daemon" : "Odebrat veškeré ExApps, nainstalované na tomto procesu služby",
    "Cancel" : "Storno",
    "Delete" : "Smazat",
    "A \"manual-install\" deploy daemon cannot be set as default" : "Proces služby „manual-install“ nemůže být nastaven jako výchozí",
    "Failed to save admin settings. Check the logs" : "Nepodařilo se uložit nastavení pro správu. Nahlédněte do záznamů událostí",
    "Password confirmation failed" : "Potvrzení hesla se nezdařilo",
    "Default" : "Výchozí",
    "Set as default" : "Nastavit jako výchozí",
    "Test deploy" : "Vyzkoušet nasazení",
    "Docker registries" : "Docker registry",
    "Edit" : "Upravit",
    "Daemon connection successful" : "Připojení ke službě úspěšné",
    "Failed to connect to the daemon. Check the logs" : "Nepodařilo se spojit s procesem služby. Nahlédněte do záznamu událostí",
    "Failed to check connection to the daemon. Check the logs" : "Nepodařilo se zkontrolovat spojení s procesem služby. Nahlédněte do záznamu událostí",
    "Unlimited" : "Neomezeně",
    "{size} GiB" : "{size} GiB",
    "{size} MiB" : "{size} MiB",
    "_{n} CPU_::_{n} CPUs_" : ["{n} procesor","{n} procesory","{n} procesorů","{n} procesory"],
    "Deploy daemon configuration" : "Nastavení procesu služby nasazování",
    "Deploy daemon configuration details" : "Podrobnosti nastavení procesu služby nasazování",
    "Deploy daemon" : "Proces nasazování",
    "Default daemon. ExApps will be installed on it" : "Výchozí proces služby. ExApps budou instalovány na něj",
    "The \"Manual install\" daemon is usually used for development. It cannot be set as the default daemon." : "Proces služby „Ruční instalace“ je obvykle používán pro vývoj. Není možné ho nastavit jako výchozí.",
    "ExApps installed" : "Nainstalované ExApps",
    "Name" : "Název",
    "Protocol" : "Protokol",
    "Host" : "Hostitel",
    "ExApp direct communication (FRP disabled)" : "Přímá komunikace ExAPP (FRP vypnuto)",
    "Deploy options" : "Předvolby nasazení",
    "Docker network" : "Síť pro Docker:",
    "Nextcloud URL" : "URL adresa Nextcloud",
    "HaProxy password" : "Heslo k HAProxy",
    "GPU support" : "Podpora GPU",
    "Computation device" : "Výpočetní zařízení",
    "Memory limit" : "Limit paměti",
    "CPU limit" : "Limit počtu jader procesoru",
    "Additional options" : "Další možnosti",
    "Check connection" : "Zkontrolovat připojení",
    "Registered Deploy daemons list" : "Seznam zaregistrovaných procesů nasazování",
    "No Deploy daemons are registered" : "Nejsou zaregistrované žádné procesy služby nasazování",
    "Register a custom one or configure one from the available templates" : "Zaregistrujte uživatelsky určené nebo nastavte z dostupných šablon",
    "Register daemon" : "Zaregistrovat proces služby",
    "Register ExApp in Nextcloud" : "Zaregistrovat ExApp v Nextcloud",
    "Check if the ExApp is registered in Nextcloud before deployment" : "Před nasazením zkontrolovat zda je ExApp zaregistrovaná v Nextcloud",
    "Image pull" : "Odeslání obrazu",
    "Check if the image is successfully pulled" : "Zkontrolovat zda je obraz úspěšně stažen",
    "Container started" : "Kontejner spuštěn",
    "Check if the image successfully pulled and container is created and started" : "Zkontrolovat zda byl obraz úspěšně natažen a vytvořen a spuštěn kontejner",
    "Heartbeat" : "Kontrola stavu",
    "Check for the heartbeat is finished and healthy" : "Kontrola funkčnosti v pořádku dokončena",
    "Init step" : "Inicializační krok",
    "Wait for initialization step to finish" : "Vyčkejte na dokončení kroku inicializace",
    "Enabled" : "Zapnuto",
    "Check if ExApp successfully handled the enabled event and registered all stuff properly" : "Zkontrolovat zda ExApp úspěšně zvládla zapnutou událost a zaregistrovala vše správně",
    "Only if ExApp container is preset" : "Pouze pokud je ExApp kontejner přítomen",
    "Deploy test passed successfully!" : "Zkouška nasazení úspěšná!",
    "Deploy test failed at step \"{step}\"" : "Zkouška nasazení se nezdařila v kroku „{step}“",
    "AppAPI will try to install small skeleton ExApp to check that the daemon is configured correctly and the deployment steps are successful." : "AppAPI se pokusí nainstalovat malou maketu ExApp kvůli kontrole, že je proces služby správně nastaven a toho, že jsou kroky nasazování úspěšné.",
    "The following deploy test checks must succeed:" : "Je třeba, aby aby následující kontroly zkoušky nasazení byly úspěšné:",
    "More information" : "Podrobnosti",
    "Download ExApp logs" : "Stáhnout si záznamy událostí v ExApp",
    "Remove the test ExApp" : "Odebrat testovací ExApp",
    "Start the deploy test" : "Spustit zkoušku nasazení",
    "Stop the deploy test" : "Zastavit zkoušku nasazení",
    "The test ExApp is unregistered and its container is removed on \"Stop the deploy test\"" : "Registrace testovací ExApp zrušena a jeho kontejner odebrán na „Zastavit zkoušku nasazení“",
    "Please enter a registry domain" : "Zadejte doménu registru",
    "\"From\" cannot be \"local\"" : "„Od“ nemůže být „local“",
    "This registry mapping already exists" : "Toto mapování registru už existuje",
    "\"From\" and \"To\" cannot be the same" : "„Od“ a „Pro“ nemůže být totéž",
    "Docker registry mapping added" : "Mapování na docker registry přidáno",
    "Error adding Docker registry mapping" : "Chyba při přidávání mapování na Docker registry",
    "Docker registry mapping removed" : "Mapování na docker registry odebráno",
    "Error removing Docker registry mapping" : "Chyba při odebírání mapování na Docker registry",
    "Override Docker registries" : "Přebít Docker registry",
    "Configure Docker registry override mappings for the selected daemon." : "Nastavit mapování přebití Docker registru pro označený proces služby.",
    "The matching source registry in ExApp info.xml will be overwritten during deployment (image pull step)." : "Odpovídající zdrojový registru v ExApp info.xml bude přebit při nasazování (krok image pull)",
    "This is useful if you want to use a custom Docker registry, for example, to use a private Docker registry, or to use a different Docker registry for testing." : "Toto se hodí pokud chcete použít uživatelsky určený Docker registru, například pro použití soukromého Docker registru, nebo pro použití odlišného Docker registru pro testování.",
    "Image pull will be skipped" : "Natažení obrazu bude přeskočeno",
    "Remove" : "Odebrat",
    "No custom Docker registries are registered" : "Nezaregistrovány žádné uživatelsky určené Docker registry",
    "Add registry override mapping" : "Přidat mapování přebití registru",
    "From" : "Od",
    "registry URL (e.g. ghcr.io)" : "URL registru (např. ghcr.io)",
    "To" : "Pro",
    "registry URL (e.g. docker.io)" : "URL registru (např. docker.io)",
    "Add" : "Přidat",
    "Hostname used by Nextcloud to access the ExApps" : "Název stroje, používaný Nextcloud pro přístup k ExApp aplikacím",
    "The hostname (and port) at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server, e.g. {host}." : "Název stroje (a číslo portu), na kterém je {name} k dispozici. Nemusí se jednat o veřejného hostitele – postačí jen takový, který je dostupný z Nextcloud serveru, např. {host}.",
    "The hostname (and port) or path at which the {name} is available. This does not need to be a public host, just a host accessible by the Nextcloud server. It can also be the path to the Docker socket. (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Název stroje (a číslo portu) nebo popis umístění, na/ve kterém je {name} k dispozici. Nemusí se jednat o veřejného hostitele – postačí jen takový, který je dostupný z Nextcloud serveru. Může se jednat také o popis umístění Docker soketu (např. nextcloud-appapi-dsp:2375, /var/run/docker.sock).",
    "A daemon with this name already exists" : "Takto nazvaný proces služby už existuje",
    "The secret key for the HaRP container communication (HP_SHARED_KEY)." : "Sdílený klíč pro komunikaci HaRP kontejneru (HP_SHARED_KEY).",
    "AppAPI Docker Socket Proxy authentication password" : "Heslo pro AppAPI Docker Socket Proxy",
    "Changes are only effective for newly installed ExApps. For existing ExApps, the Docker containers should be recreated to apply the new settings values." : "Změny jsou uplatněny pouze pro nově instalované ExApp aplikace. Pro stávající ExApps, aby nové hodnoty nastavení byly uplatněny, by měly Docker kontejnery být znovu vytvořeny.",
    "The Docker network that the deployed ExApps will use." : "Docker síť kterou budou nasazované ExApps aplikace používat.",
    "The URL should start with http:// or https://" : "URL by měly začínat na http:// nebo https://",
    "For a HTTPS daemon, the Nextcloud URL should be HTTPS" : "Pro HTTPS proces služby, URL Nextcloud by měla být HTTPS",
    "All available GPU devices on the daemon host need to be enabled in ExApp containers by Docker." : "Na hostiteli procesů služeb bude třeba, aby veškerá GPU zařízení byla Dockerem zpřístupněna v kontejnerech ExApp aplikací.",
    "DaemonConfig successfully registered" : "DaemonConfig úspěšně zaregistrován",
    "Failed to register DaemonConfig. Check the logs" : "Nepodařilo se zaregistrovat DaemonConfig. Nahlédněte do záznamu událostí",
    "DaemonConfig successfully updated" : "DaemonConfig úspěšně zaktualizován",
    "Failed to update DaemonConfig. Check the logs" : "Nepodařilo se zaktualizovat DaemonConfig. Nahlédněte do záznamu událostí",
    "Failed to connect to Daemon. Check the logs" : "Nepodařilo se spojit s procesem služby. Nahlédněte do záznamu událostí",
    "Failed to check connection to Daemon. Check the logs" : "Nepodařilo se zkontrolovat spojení s procesem služby. Nahlédněte do záznamu událostí",
    "Edit the deploy daemon" : "Upravit proces služby nasazován",
    "Register a new deploy daemon" : "Zaregistrovat nový proces služby nasazování",
    "Daemon configuration template" : "Šablona nastavení procesu služby",
    "Select a daemon configuration template" : "Vyberte šablonu nastavení procesu služby",
    "Daemon registration form" : "Formulář registrace procesu služby",
    "Unique deploy daemon name" : "Neopakující se název procesu služby nasazování",
    "Unique deploy Daemon name" : "Neopakující se název procesu služby nasazování",
    "Display name" : "Zobrazované jméno",
    "Deployment method" : "Metoda nasazování",
    "Select the daemon deploy method" : "Vyberte metodu nasazování procesu služby",
    "HaRP host" : "Hostitel s HaRP",
    "Daemon host" : "Hostitel procesu služby",
    "HaRP shared key" : "Sdílený klíč HaRP",
    "The password must be at least 12 characters long" : "Je třeba, aby heslo bylo alespoň 12 znaků dlouhé",
    "Set this daemon as the default one" : "Nastavit tento proces služby jako výchozí",
    "Set as the default daemon" : "Nastavit jako výchozí proces služby",
    "Enable HTTPS" : "Zapnout HTTPS",
    "Show deploy options" : "Zobrazit předvolby nasazení",
    "Hide deploy options" : "Skrýt předvolby nasazen",
    "Enable HaRP" : "Zapnout HaRP",
    "FRP server address" : "Adresa FRP serveru",
    "The address (host:port) of the FRP server that should be reachable by the ExApp in the network defined in the 'Docker network' section." : "Adresa (hostitel:port) FRP serveru, který by měl být dosažitelný ExApp v síti, definované v sekci 'Docker Network'.",
    "Docker socket proxy port" : "Port Docker proxy soketu",
    "The port in HaRP which the Docker socket proxy connects to. This should be exposed but for the in-built one, it is not required to be exposed or changed." : "Port v HaRP, ke kterému se proxy Docker soketu připojuje. Toto by mělo být exponováno, ale pro vestavěné, není vyžadováno, aby bylo exponováno nebo změněno.",
    "Disable FRP" : "Vypnout FRP",
    "Flag for advanced setups only. Disables the FRP tunnel between ExApps and HaRP." : "Příznak pouze pro pokročilá uspořádání. Vypíná FRP tunel mezi ExApplikacem a HaRP.",
    "Docker network for ex-app deployment must be defined" : "Je třeba definovat Docker síť pro nasazování ex-app",
    "Compute device" : "Výpočetní zařízení",
    "Memory limit (in MiB)" : "Limit paměti (v MiB)",
    "Must be a positive integer" : "Je třeba, aby bylo celé kladné číslo",
    "Maximum amount of memory that the ExApp container can use in mebibytes" : "Kolik operační paměti nejvýše bude moci ExApp kontejner využívat (v MiB)",
    "CPU limit as decimal value" : "Limit na procesor (jako desítková hodnota)",
    "Must be a positive number" : "Je třeba, aby bylo kladné číslo",
    "Maximum number of CPU cores that the ExApp container can use (e.g. 0.5 for half a core, 2 for two cores)" : "Kolik jader procesoru nejvýše bude moci ExApp kontejner využívat (např. 0.5 pro půl jádra, 2 pro dvě jádra)",
    "Add additional option" : "Přidat další volbu",
    "Option key (unique)" : "Klíč volby (neopakující se)",
    "Option key (unique, e.g. my_key)" : "Klíč volby (neopakující se, např. muj_klic)",
    "Option key is required" : "Klíč volby je vyžadován",
    "Option value" : "Hodnota volby",
    "Option value is required" : "Je zapotřebí klíč volby",
    "Confirm" : "Potvrdit",
    "Save" : "Uložit",
    "Register" : "Registrovat",
    "External Apps" : "Externí aplikace",
    "The AppAPI Project is an exciting initiative that aims to revolutionize the way applications are developed for Nextcloud." : "Projekt AppAPI je vzrušující iniciativa která má za cíl zcela změnit způsob, kterým jsou vyvíjeny aplikace pro Nextcloud.",
    "Deploy Daemons" : "Nasadit procesy služeb",
    "Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Proces služby nasazování (DaemonConfig) slouží pro orchestraci ExApps.",
    "Deploy Daemons. Deploy Daemon (DaemonConfig) is an ExApps orchestration daemon." : "Procesy nasazování. Proces služby nasazování (DaemonConfig) slouží pro orchestraci ExApps.",
    "Default Deploy Daemon is not accessible. Please verify its configuration" : "Výchozí proces služby nasazování není dostupný. Ověřte její nastavení",
    "Specify container restart policy, e.g. 'always' to ensure ExApp running after daemon server reboot" : "Určete zásadu pro restartování kontejneru – například 'always', která zajistí že ExApp bude spuštěna po restartu serveru s procesem služby",
    "This settings changes are reflected only for newly created containers" : "Změny tohoto nastavení se budou týkat pouze nově vytvářených kontejnerů",
    "{license}-licensed" : "licencováno pod {license}",
    "Update to {version}" : "Aktualizovat na {version}",
    "Delete data on remove" : "Při odebrání smazat data",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavený žádný požadavek na minimální verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tato aplikace nemá nastavenou žádnou nejvyšší podporovanou verzi Nextcloud. To v budoucnu bude hodnoceno jako chyba.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tuto aplikaci nelze nainstalovat, protože nejsou splněny následující závislosti:",
    "View in store" : "Zobrazit v katalogu aplikací",
    "Visit website" : "Navštívit webovou stránku",
    "Report a bug" : "Nahlásit chybu",
    "User documentation" : "Dokumentace pro uživatele",
    "Admin documentation" : "Dokumentace pro správce",
    "Developer documentation" : "Dokumentace pro vývojáře",
    "This app is not registered in AppStore. No extra information available. Only enable/disable and remove actions are allowed." : "Tato aplikace není zaregistrována v katalogu aplikací. Tím nejsou k dispozici žádné další informace. Je možné pouze zapnout/vypnout a odebrat.",
    "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného podpory Nextcloud.",
    "Supported" : "Podporováno",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Doporučované aplikace jsou vyvíjeny komunitou. Jsou propojeny se zbytkem Nextcloud a připraveny na produkční nasazení.",
    "Featured" : "Doporučené",
    "Update to {update}" : "Aktualizovat na {update}",
    "All ExApps are up-to-date." : "Všechny ExApps jsou aktuální.",
    "Default Deploy daemon is not accessible" : "Výchozí proces služby nasazování není dostupný",
    "Icon" : "Ikona",
    "Version" : "Verze",
    "Daemon" : "Proces služby",
    "Level" : "Stupeň podrobnosti/závažnosti",
    "Actions" : "Akce",
    "Results from other categories" : "Výsledky z ostatních kategorií",
    "No apps found" : "Nenalezeny žádné aplikace",
    "_%n ExApp has an update available_::_%n apps have an update available_" : ["pro %n ExApp je k dispozici aktualizace","pro %n aplikace jsou k dispozici aktualizace","pro %n aplikací jsou k dispozici aktualizace","pro %n aplikace jsou k dispozici aktualizace"],
    "_Update_::_Update all_" : ["Aktualizovat","Aktualizovat vše","Aktualizovat vše","Aktualizovat vše"],
    "Deploy Daemon" : "Nasadit proces služby",
    "Type" : "Typ",
    "Display Name" : "Zobrazované jméno",
    "GPUs support" : "Podpora pro výpočty na GPU",
    "Are you sure you want delete Deploy Daemon" : "Opravdu chcete proces nasazování smazat",
    "All ExApps on this daemon will be removed" : "Veškeré ExApps na tomto procesu služby byly odebrány",
    "All ExApps installed on this daemon will be removed" : "Veškeré ExApps nainstalované na tomto procesu služby byly odebrány",
    "\"manual-install\" Deploy Daemon cannot be set as default" : "Proces služby „manual-install“ nemůže být nastaven jako výchozí",
    "Failed to save admin options. Check the logs" : "Nepodařilo se uložit nastavení pro správu. Nahlédněte do záznamů událostí",
    "Deploy daemon config details" : "Podrobnosti nastavení procesu služby nasazování",
    "Manual install daemon usually used for development. It cannot be set as default daemon." : "Proces služby ruční instalace je obvykle používán pro vývoj. Není možné ho nastavit jako výchozí.",
    "Deploy config" : "Nastavení nasazení",
    "Verify connection" : "Ověřit připojení",
    "No Deploy daemons configured" : "Nejsou nastavené žádné procesy služby nasazování",
    "Register a custom one or setup from available templates" : "Zaregistrujte uživatelsky určené nebo nastavte z dostupných šablon",
    "Register Daemon" : "Zaregistrovat proces služby",
    "AppAPI will try to install small skeleton ExApp to verify Daemon configured correctly and deployment steps are passing." : "AppAPI se pokusí nainstalovat malou maketu ExApp kvůli ověření správného nastavení procesu služby a toho, že procházejí kroky nasazování.",
    "The following Deploy test checks must be passed to succeed:" : "Pro úspěch je třeba, aby následující kontroly zkoušky nasazení prošly:",
    "More info" : "Další informace",
    "Remove test ExApp" : "Odebrat testovací ExApp",
    "Start Deploy test" : "Spustit zkoušku nasazení",
    "Stop Deploy test" : "Zastavit zkoušku nasazení",
    "ExApp is unregistered and container is removed on \"Stop deploy test\"" : "Registrace ExApp zrušena a kontejner odebrán na „Zastavit zkoušku nasazení“",
    "Hostname to access ExApps" : "Název stroje pro přístup k ExApps",
    "Hostname or path to access Docker daemon (e.g. nextcloud-appapi-dsp:2375, /var/run/docker.sock)" : "Název stroje nebo popis umístění pro přístup k procesu služby Docker (např. nextcloud-appapi-dsp:2375, /var/run/docker.sock)",
    "Daemon with this name already exists" : "Takto nazvaný proces služby už existuje",
    "Password must be at least 12 characters long" : "Je třeba, aby heslo bylo alespoň 12 znaků dlouhé",
    "With https enabled network is set to host" : "V případě sítě podporující https je nastaveno na hostitele",
    "Changes would be applied only for newly installed ExApps. For existing ExApps, Docker containers should be recreated." : "Změny by měly být uplatněny pouze pro nově instalované ExApps. Pro stávající ExApps by měly být znovu vytvořeny Docker kontejnery.",
    "URL should start with http:// or https://" : "URL by měly začínat na http:// nebo https://",
    "For HTTPS daemon, Nextcloud URL should be HTTPS" : "Pro HTTPS proces služby, URL Nextcloud by měla být HTTPS",
    "All available GPU devices on daemon host will be requested to be enabled in ExApp containers by Docker." : "Na hostiteli procesů služeb bude zažádáno o to, aby veškerá GPU zařízení byla Dockerem zpřístupněna v kontejnerech ExApp aplikací.",
    "Edit Deploy Daemon" : "Upravit proces služby nasazován",
    "Register Deploy Daemon" : "Zaregistrovat proces služby nasazování",
    "Select daemon configuration template" : "Vyberte šablonu nastavení procesu služby",
    "Unique Deploy Daemon Name" : "Neopakující se název procesu služby nasazování",
    "Select daemon deploy method" : "Vyberte metodu nasazování procesu služby",
    "Set daemon as default" : "Nastavit proces služby jako výchozí",
    "Set as default daemon" : "Nastavit jako výchozí proces služby",
    "Enable https" : "Zapnout https",
    "Show deploy config" : "Zobrazit nastavení nasazení",
    "Hide deploy config" : "Skrýt nastavení nasazení",
    "Network" : "Síť",
    "Docker network name" : "Název Docker sítě",
    "Additional option" : "Další volba",
    "by {author}\n{license}" : "od {author}\n{license}",
    "Your apps" : "Vaše aplikace",
    "Documentation" : "Dokumentace",
    "Details" : "Podrobnosti",
    "Changelog" : "Souhrn změn",
    "Active apps" : "Aktivní aplikace",
    "Disabled apps" : "Vypnuté aplikace",
    "Updates" : "Aktualizace",
    "Featured apps" : "Doporučené aplikace",
    "Supported apps" : "Podporované aplikace",
    "manual-install apps cannot be updated" : "ručně nainstalované aplikace není možné zaktualizovat",
    "{progress}% Deploying" : "{progress}% nasazování",
    "{progress}% Initializing" : "{progress}% inicializuje se",
    "Healthchecking" : "Kontrola stavu",
    "Deploy and Enable" : "Nasadit a zapnout",
    "Enable" : "Povolit",
    "Disable" : "Vypnout",
    "Allow untested app" : "Umožnit nevyzkoušenou aplikaci",
    "Default Deploy daemon is not accessible. Please verify configuration" : "Výchozí proces služby nasazování není dostupný. Ověřte nastavení",
    "The app will be downloaded from the App Store and deployed on default Deploy Daemon" : "Aplikace bude stažena z katalogu aplikací a nasazena na výchozí proces služby pro nasazení",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tato aplikace není označena jako kompatibilní s vámi používanou verzí Nexcloud. Pokud budete pokračovat, pořád budete moci aplikaci nainstalovat. Uvědomte si ale, že aplikace nemusí fungovat, jak je očekáváno.",
    "Your ExApps" : "Vaše ext. aplikace",
    "An error occurred during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
    "The app has been enabled but needs to be updated." : "Aplikace byla zapnuta, ale je třeba ji zaktualizovat.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
